@@ -93,7 +93,7 @@ START_TEST (test_ctrl_char_strip)
     const char test_str[] = {'t',0x02,'e','s','t','f',0x06,0x07,0x08,0x09,
 			     'o',0x0B,'o',0x0C,0x0E,0x0F,0x10,0x11,0x12,
 			     0x13,0x14,0x15,0x16,0x17,0x18,0x19,0x1A,0x1B,
-			     0x1C,0x1D,0x1E,0x1F,0x7F,'b','a','r'};
+			     0x1C,0x1D,0x1E,0x1F,0x7F,'b','a','r', '\0'};
 
      const char valid_str[] = {'t',' ','e','s','t','f',' ',' ',' ',' ',
 			       'o',' ','o',' ',' ',' ',' ',' ',' ',
@@ -149,26 +149,32 @@ START_TEST (test_logging)
     
     /* Back to terminal. */
     freopen ("/dev/tty", "w", stdout);
-
+    fflush (fp);
+    fclose (fp);
+    sleep (1);
     // And verify messages. */
-    sprintf (cmd, "grep \"[INFO]* INFO message: This works.\" %s", stdout_tmp); 
-    ret = system (cmd);
-    fail_if (ret != 0, cmd);
-    
-    sprintf (cmd, "grep \"[WARNING]* WARNING message: This works.\" %s", 
+    sprintf (cmd, "grep -q \"[INFO]* INFO message: This works.\" %s", 
 	     stdout_tmp); 
     ret = system (cmd);
     fail_if (ret != 0, cmd);
     
-    sprintf (cmd, "grep \"[ERROR]* ERROR message: This works.\" %s", stdout_tmp); 
+    sprintf (cmd, "grep -q \"[WARNING]* WARNING message: This works.\" %s", 
+	     stdout_tmp); 
     ret = system (cmd);
     fail_if (ret != 0, cmd);
     
-    sprintf (cmd, "grep aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaab %s", stdout_tmp); 
+    sprintf (cmd, "grep -q \"[ERROR]* ERROR message: This works.\" %s", 
+	     stdout_tmp); 
+    ret = system (cmd);
+    fail_if (ret != 0, cmd);
+    
+    sprintf (cmd, "grep -q aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaab %s", 
+	     stdout_tmp); 
     ret = system (cmd);
     fail_if (ret != 0, cmd);
 
-    sprintf (cmd, "grep bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb %s", stdout_tmp); 
+    sprintf (cmd, "grep -q bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb %s", 
+	     stdout_tmp); 
     ret = system (cmd);
     fail_unless (ret != 0, cmd);
 
@@ -177,7 +183,8 @@ START_TEST (test_logging)
     LOG_MSG (LOG_DEBUG, "DEBUG message: %s\n", "This should not work.");
     freopen ("/dev/tty", "w", stdout);
     
-    sprintf (cmd, "grep \"[DEBUG]* DEBUG message: This should not work.\" %s", stdout_tmp); 
+    sprintf (cmd, "grep -q \"[DEBUG]* DEBUG message: This should not work.\""
+	     " %s", stdout_tmp); 
     ret = system (cmd);
     fail_if (ret == 0, cmd);
     
@@ -198,19 +205,23 @@ START_TEST (test_logging)
     freopen ("/dev/tty", "w", stdout);
 
     // And verify messages. */
-    sprintf (cmd, "grep \"[INFO]* INFO message: This works.\" %s", stdout_tmp); 
+    sprintf (cmd, "grep -q \"[INFO]* INFO message: This works.\" %s", 
+	     stdout_tmp); 
     ret = system (cmd);
     fail_if (ret != 0, cmd);
     
-    sprintf (cmd, "grep \"[WARNING]* WARNING message: This works.\" %s", stdout_tmp); 
+    sprintf (cmd, "grep -q \"[WARNING]* WARNING message: This works.\" %s", 
+	     stdout_tmp); 
     ret = system (cmd);
     fail_if (ret != 0, cmd);
     
-    sprintf (cmd, "grep \"[ERROR]* ERROR message: This works.\" %s", stdout_tmp); 
+    sprintf (cmd, "grep -q \"[ERROR]* ERROR message: This works.\" %s", 
+	     stdout_tmp); 
     ret = system (cmd);
     fail_if (ret != 0, cmd);
     
-    sprintf (cmd, "grep \"[DEBUG]* DEBUG message: This works.\" %s", stdout_tmp); 
+    sprintf (cmd, "grep -q \"[DEBUG]* DEBUG message: This works.\" %s", 
+	     stdout_tmp); 
     ret = system (cmd);
     fail_if (ret != 0, cmd);
     
@@ -226,7 +237,8 @@ START_TEST (test_logging)
     /* Back to terminal. */
     freopen ("/dev/tty", "w", stdout);
     
-    sprintf (cmd, "grep \"[INFO]* INFO message: Silent mode.\" %s", stdout_tmp); 
+    sprintf (cmd, "grep -q \"[INFO]* INFO message: Silent mode.\" %s", 
+	     stdout_tmp); 
     
     ret = system (cmd);
     fail_if (ret == 0, cmd);
